Before contributing to this repository, please first discuss the change you wish to make via issue, email, or any other method with the owners of this repository before making a change.

### Pull Request Process

1. After you have forked this repository, you could use `make install` for *the first time* to install the local development dependencies; afterward, you may use `make dev` to build the library when you have made any code changes.
2. Before committing your changes, you can use `make format && make lint` to ensure the codes follow our style standards.
3. Please add corresponding tests to your change if that's related to new feature or API, and ensure `make test` can pass.
4. Submit your pull request.

### Contacts

- Keming <kemingy94@gmail.com>
- zclzc <lkevinzc@gmail.com>
